@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::ModuleDev; # git description: v0.38-56-g51d2c81
+package Task::Kensho::ModuleDev; # git description: v0.39-56-ge61f07a
 # ABSTRACT: A Glimpse at an Enlightened Perl: Module Development
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::ModuleDev - A Glimpse at an Enlightened Perl: Module Development
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -66,7 +66,7 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
-=for stopwords profiler templated
+=for stopwords profiler templated tidyall validator
 
 =head2 L<Task::Kensho::ModuleDev>: Module Development
 
@@ -74,6 +74,10 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 Upload things to the CPAN
 
+=head3 L<Code::TidyAll>
+
+Engine for tidyall, your all-in-one code tidier and validator
+
 =head3 L<Data::Printer>
 
 Colored pretty-print of Perl data structures and objects
@@ -110,10 +114,6 @@ Critique Perl source code for best-practices.
 
 Parses and beautifies perl source
 
-=head3 L<Perl::Version>
-
-Parse and manipulate Perl version strings
-
 =head3 L<Pod::Readme>
 
 Convert POD to README file
@@ -159,7 +159,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Olaf Alders Dan Book Rachel Kelly Shawn Sorichetti Rick Leir
 
 =over 4
 
@@ -177,6 +177,22 @@ Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Dan Book <grinnz@gmail.com>
+
+=item *
+
+Rachel Kelly <rkellyalso@gmail.com>
+
+=item *
+
+Shawn Sorichetti <shawn@coloredblocks.com>
+
+=item *
+
 Rick Leir <rleir@leirtech.com>
 
 =back
